@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-import datetime
 import itertools
 import re
 
@@ -162,6 +161,8 @@ gentation_to_number = {
     'guys who like girls': '17',
     'girls who like girls': '40',
     'guys who like guys': '20',
+    'guys and girls who like bi guys': '54',
+    'guys and girls who like bi girls': '57',
     'both who like bi guys': '54',
     'both who like bi girls': '57',
     'straight girls only': '2',
@@ -201,9 +202,12 @@ def get_height_filter(height_min=None, height_max=None):
 
 
 def parse_height_string(height_string):
+    if not height_string:
+        return 0
     match = imperial_re.search(height_string)
     if match:
-        return int(round(inches_to_centimeters(int(match.group(1)) * 12 + int(match.group(2)))))
+        return int(round(inches_to_centimeters(int(match.group(1)) * 12 +
+                                               int(match.group(2)))))
     match = metric_re.search(height_string)
     if match:
         meters = float(match.group(1))
